#define XERR
#include "scenario.ih"

size_t Scenario::value(char const *id) const
{
    auto single = find(id);

    try
    {
        return single.iter == end() ? 0 : stoul(single.iter->value());
    }
    catch (...)
    {
        Error::instance()(single.src, single.iter->lineNr(),     //  (
                                    MISSING_NR) << id << "')\n";
        return string::npos;
    }
}
